#!/bin/bash -

# The script used to install guests on RHEL 5 Xen.

# NB: You have to run this script on the RHEL 5 Xen host itself.
if ! uname -a | grep -sq 'el5xen'; then
    echo "$0: You must run this on RHEL 5 Xen host"
    exit 1
fi

if [ $# -ne 4 ]; then
    echo "$0 major minor arch pv|fv"
    exit 1
fi

# Ancient RHEL versions didn't work very well headless.  I cannot
# get RHEL 4 to install at all.
if [ "$DISPLAY" = "" ]; then
    echo "$0: DISPLAY variable is not set"
    exit 1
fi

major=$1
minor=$2
arch=$3
pvfv=$4
name=rhel_${major}${minor}_${arch}_${pvfv}

case $major in
    3)
        tree=http://tock/download/released/RHEL-$major/U$minor/AS/$arch/tree
        ;;
    4)
        tree=http://tock/download/released/RHEL-$major/U$minor/AS/$arch/tree
        ;;
    5)
        tree=http://tock/download/released/RHEL-$major-Server/U$minor/$arch/os
        ;;
    6)
        # https://access.redhat.com/documentation/en-US/Red_Hat_Enterprise_Linux/5/html/Virtualization/chap-RHEL6_On_RHEL5.html
        # In theory the paravirt-opts RHEL 6 kernel should be
        # installable as a PV guest on RHEL 5 Xen, but I could not
        # make it work.
        tree=http://tock/download/released/RHEL-$major/$major.$minor/Server/$arch/os
        ;;
    *)
        echo "$0: $major.$minor not supported yet"
        exit 1
esac

echo tree=$tree

case $pvfv in
    pv)
        pvfv_option=--paravirt
        ;;
    fv)
        pvfv_option=--hvm
        ;;
    *)
        echo "$0: the fourth parameter must be [pv|fv]"
        exit 1
esac

# Create the kickstart.
#
# RHEL 5 didn't have virt-install --initrd-inject, so the following
# only works because I have a webserver and an NFS server which map
# the same directory.
webserver=http://192.168.0.249/scratch
nfsserver=/mnt/scratch
ks=$(mktemp -p $nfsserver)
cat > $ks <<EOF
install
url --url $tree
text
lang en_US.UTF-8
keyboard us
network --bootproto dhcp
rootpw 123456
firewall --enabled --ssh
timezone --utc America/New_York
EOF

if [ $major -ge 4 ]; then
    echo "selinux --enforcing" >> $ks
    echo "poweroff" >> $ks
fi

# This doesn't work on RHEL 5.  Didn't check RHEL 6 yet.
#if [ $major -ge 5 ]; then
#    echo "hostname $name" >> $ks
#fi

cat >> $ks <<EOF

zerombr
clearpart --all --initlabel
autopart

xconfig --defaultdesktop=GNOME

%packages
@core
@gnome-desktop
@admin-tools
@system-tools
EOF
chmod 0644 $ks

ks_url="$webserver/`basename $ks`"
echo ks=$ks_url

# Output disk.
echo Creating the output disk ...
output=/mnt/fastscratch/$name.img
rm -f $output
dd if=/dev/zero of=$output bs=1 count=0 seek=6G

virsh destroy $name ||:
virsh undefine $name ||:

set -e

echo Running virt-install ...
virt-install \
    $pvfv_option \
    --name=$name \
    --ram=1024 \
    --vcpus=1 \
    --os-type=linux --os-variant=rhel$major \
    --file=$output \
    --location=$tree \
    --extra-args="ks=$ks_url"

virsh dumpxml $name > /mnt/fastscratch/$name.xml

echo Output written to /mnt/fastscratch:
ls -l /mnt/fastscratch/$name*
